import os
import unittest

from auto_cmake.auto_cmake_android import AutoCMakeLibSharedAndroid

# Source paths
proj_dir = os.path.abspath(os.path.join(os.getcwd(), "resources", "sample_c_proj"))
build_dir = os.path.abspath(os.path.join(os.getcwd(), "resources", "sample_android_proj", "sample_lib_shared_android", "src", "main", "cpp"))

# Configuration
cmake_config = dict()
cmake_config['proj_name'] = 'sample_lib_shared_android'
cmake_config['proj_dir'] = proj_dir
cmake_config['version'] = "2024.03.08"
cmake_config['cmake_version'] = '3.22.1'
cmake_config['include_dirs'] = [proj_dir, build_dir]
cmake_config['libs'] = []
cmake_config['flags'] = []
cmake_config['exclude_dirs'] = ['test', 'cmake-build-debug', 'build']
cmake_config['exclude_paths'] = []
cmake_config['build_dir'] = build_dir

class TestAutoCMakeLibStaticIos(unittest.TestCase):

    def test_build_lib_shared_android(self):
        ac = AutoCMakeLibSharedAndroid(**cmake_config)
        ac.run()

if __name__ == '__main__':
    unittest.main()



import os
import unittest

from auto_cmake.auto_cmake_exe import AutoCMakeExe

# Source paths
proj_dir = os.path.abspath(os.path.join(os.getcwd(), "resources", "sample_c_proj"))
build_dir = os.path.abspath(os.path.join(proj_dir, "build"))

# Configuration
cmake_config = dict()
cmake_config['proj_name'] = 'sample_c_proj'
cmake_config['proj_dir'] = proj_dir
cmake_config['version'] = "2024.03.08"
cmake_config['cmake_version'] = '3.15'
cmake_config['include_dirs'] = [proj_dir]
cmake_config['libs'] = []
cmake_config['flags'] = []
cmake_config['exclude_dirs'] = []
cmake_config['exclude_paths'] = []
cmake_config['build_dir'] = build_dir

class TestAutoCMakeExe(unittest.TestCase):

    def test_build_exe(self):
        ac = AutoCMakeExe(**cmake_config)
        ac.run()

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python

"""
Description: Generates an executable target
"""

__author__ = "Veda Sadhak"
__license__ = "MIT"

import os
import shutil

from .auto_cmake import AutoCMake

class AutoCMakeSTM32():

    def __init__(self, **cmake_config):

        # Creating instance
        self.ac = AutoCMake(**cmake_config)

        # Setting flags
        self.linker_file = cmake_config["linker_file"]
        self.c_flags = cmake_config["c_flags"]
        self.cxx_flags = cmake_config["cxx_flags"]

        self.compile_options = ""
        for option in cmake_config["compile_options"]:
            self.compile_options += option + " "

        self.link_options = ""
        for option in cmake_config["link_options"]:
            self.link_options += option + " "

        self.definitions = ""
        for definition in cmake_config["definitions"]:
            self.definitions += definition + " "

    def run(self):

        # Recursively adding all source
        for _dir in self.ac.include_dirs:
            self.ac.add_libraries(os.path.join(self.ac.proj_dir, _dir))
            self.ac.clear()

        # Adding the compile config
        self.ac.add("cmake_minimum_required(VERSION {})".format(self.ac.cmake_version))
        self.ac.add("project({} VERSION {})".format(self.ac.proj_name, self.ac.version))
        self.ac.add("set(CMAKE_CXX_STANDARD 11)")
        self.ac.add('set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS}")\n')

        # Set headers and sources
        self.ac.add("set(SOURCES".format(self.ac.proj_name))
        for source in self.ac.sources:
            self.ac.add('    "{}"'.format(self.ac.get_posix_path(source)))
        for headers in self.ac.headers:
            self.ac.add('    "{}"'.format(self.ac.get_posix_path(headers)))
        self.ac.add(")\n")

        # Adding the startup file
        if (len(self.ac.startup) != 1):
            raise Exception(f"Invalid number of startup files: {len(self.ac.startup)}")
        else:
            startup_file = self.ac.startup[0]
            self.ac.add(f'add_library(STARTUP "{startup_file}")')
            self.ac.add(f'set_source_files_properties("{startup_file}" PROPERTIES COMPILE_FLAGS "-x assembler-with-cpp")')
            self.ac.add(f'set_property(SOURCE "{startup_file}" PROPERTY LANGUAGE C)')
            self.ac.add("")

        # Add the compiler
        self.ac.add("set(CMAKE_C_COMPILER arm-none-eabi-gcc)")
        self.ac.add("set(CMAKE_CXX_COMPILER arm-none-eabi-g++)")
        self.ac.add("set(OBJCOPY arm-none-eabi-objcopy)")
        self.ac.add("")

        # Find linker path
        if not self.linker_file:
            raise Exception(f"No linker specified.")
        elif len(self.ac.linkers) == 0:
            raise Exception(f"No linkers found.")
        else:
            for linker_path in self.ac.linkers:
                if self.linker_file in linker_path:
                    self.linker_path = linker_path

        # Setup linker
        self.ac.add(f'set(COMMON_FLAGS "{self.compile_options}")')
        self.ac.add(f'set(CMAKE_C_FLAGS "{self.compile_options} {self.c_flags}")')
        self.ac.add(f'set(CMAKE_CXX_FLAGS "{self.compile_options} {self.cxx_flags}")')
        self.ac.add(f'set(CMAKE_EXE_LINKER_FLAGS "{self.link_options} -T {self.linker_path}")')
        self.ac.add("")

        # Adding the executable
        self.ac.add("add_executable({}.elf {} {})\n".format(self.ac.proj_name, r"${SOURCES}", r"${LINKER_SCRIPT}"))
        self.ac.add("")

        # Adding include directories
        for path in self.ac.library_paths:
            self.ac.add('target_include_directories({}.elf PUBLIC "{}")'.format(self.ac.proj_name, path))
        self.ac.add("")

        # Setting flags
        self.ac.add(f'target_compile_definitions({self.ac.proj_name}.elf PRIVATE {self.definitions})')
        self.ac.add("")

        # Setup build files
        self.ac.add('target_link_libraries(${PROJECT_NAME}.elf STARTUP)')
        self.ac.add('set(CMAKE_EXE_LINKER_FLAGS "${CMAKE_EXE_LINKER_FLAGS} -Wl,-gc-sections,--print-memory-usage,-Map=${PROJECT_NAME}.map")')
        self.ac.add('set(HEX_FILE ${PROJECT_SOURCE_DIR}/${PROJECT_NAME}.hex)')
        self.ac.add('set(BIN_FILE ${PROJECT_SOURCE_DIR}/${PROJECT_NAME}.bin)')
        self.ac.add("")

        # Setup build command
        self.ac.add(r'add_custom_command(TARGET ${PROJECT_NAME}.elf POST_BUILD')
        self.ac.add(r'                   COMMAND ${OBJCOPY} -Oihex ${PROJECT_NAME}.elf ${HEX_FILE}')
        self.ac.add(r'                   COMMAND ${OBJCOPY} -Obinary ${PROJECT_NAME}.elf ${BIN_FILE}')
        self.ac.add(r'                   COMMENT "Building ${HEX_FILE} \nBuilding ${BIN_FILE}"')
        self.ac.add(r'                   COMMAND arm-none-eabi-size ${PROJECT_NAME}.elf)')
        self.ac.add("")

        # Writing main CMakeLists.txt
        self.ac.create_build_dir()
        self.ac.write(self.ac.build_dir)

        # Copy toolchain file
        src_file = self.ac.get_posix_path(os.path.join(self.ac.proj_dir, "Scripts", "cmake", "auto_cmake", "resources", "arm-none-eabi-gcc.toolchain.cmake"))
        dst_file = self.ac.get_posix_path(os.path.join(self.ac.proj_dir, "cmake-build-debug", "arm-none-eabi-gcc.toolchain.cmake"))
        shutil.copyfile(src_file, dst_file)


#!/usr/bin/env python

"""
Description: Generates a macosx shared library
"""

__author__ = "Veda Sadhak"
__license__ = "MIT"

import os.path

from pbxproj import XcodeProject

from .auto_cmake import AutoCMake

class AutoCMakeLibStaticIos():

    def __init__(self, **cmake_config):

        # Creating instance
        self.ac = AutoCMake(**cmake_config)

        # Public headers
        if "public_headers" in cmake_config.keys():
            self.public_headers = cmake_config["public_headers"]

        # XCode proj path
        if "xcode_proj" in cmake_config.keys():
            self.xcode_proj = self.ac.get_posix_path(cmake_config["xcode_proj"])
        else:
            raise ("cmake_config['xcode_proj'] must be specified (e.g. an empty XCode Static Lib project")

    # def xcode_find_file(self, project, file_path):
    #     file_name = os.path.basename(file_path)
    #     for file in project..files:
    #         if file_name == file.get('name') or file_name == file.get('path').split('/')[-1]:
    #             return file
    #     return None

    def xcode_find_file(self, project, file_path):
        file_name = os.path.basename(file_path)
        # Iterate over all PBXFileReference objects in the project
        for obj in project.objects.get_objects_in_section('PBXFileReference'):
            # Access the 'name' and 'path' attributes directly, with a fallback
            obj_name = obj.name if 'name' in obj else None
            obj_path = obj.path if 'path' in obj else None

            # Now compare using these variables
            if file_name == obj_name or file_name == obj_path.split('/')[-1]:
                return obj
        return None

    def xcode_rmv_header(self, project, header):
        for target in project.objects.get_targets():
            file = self.xcode_find_file(project, header)
            if file:
                for config in project.objects[target.buildConfigurationList].buildConfigurations:
                    # Each config is a reference to a PBXBuildConfiguration object
                    # You can access its buildSettings dictionary directly
                    build_settings = project.objects[config].buildSettings
                    if 'LIBRARY_SEARCH_PATHS' in build_settings:
                        library_search_paths = build_settings['LIBRARY_SEARCH_PATHS']

                        if header in library_search_paths:
                            library_search_paths.remove(header)
                            build_settings['LIBRARY_SEARCH_PATHS'] = library_search_paths

                        dir = os.path.dirname(file.path)
                        if type(library_search_paths) == list:
                            for path in library_search_paths:
                                if dir in path:
                                    library_search_paths.remove(path)
                                    build_settings['LIBRARY_SEARCH_PATHS'] = library_search_paths
                        elif type(library_search_paths) == str:
                            if dir in library_search_paths:
                                build_settings['LIBRARY_SEARCH_PATHS'] = ''

                # Update header search paths
                project.remove_header_search_paths(header, target_name=target.name)
                project.remove_header_search_paths(file.path, target_name=target.name)

                # Remove file
                project.remove_file_by_id(file.get_id())

    def xcode_add_headers(self):

        # Load XCode project
        project = XcodeProject.load(self.xcode_proj)

        # Add header paths to all targets in the project
        for header in self.ac.headers:
            self.xcode_rmv_header(project, header)
            for target in project.objects.get_targets():
                project.add_header_search_paths([header], target_name=target.name, recursive=False)
                project.add_file(header, parent=None, tree='SOURCE_ROOT', target_name=target.name)

        # Save the project file
        project.save()

    def xcode_add_sources(self):

        # Load XCode project
        project = XcodeProject.load(self.xcode_proj)

        # Add header paths to all targets in the project
        for target in project.objects.get_targets():
            for source in self.ac.sources:
                file = self.xcode_find_file(project, source)
                if file:
                    project.remove_file_by_id(file.get_id())
                project.add_file(source, target_name=target.name)

        # Save the project file
        project.save()

    def xcode_rmv_headers(self):

        # Load XCode project
        project = XcodeProject.load(self.xcode_proj)

        # Add header paths to all targets in the project
        for header in self.ac.headers:
            self.xcode_rmv_header(project, header)

        # Save the project file
        project.save()

    def xcode_rmv_sources(self):

        # Load XCode project
        project = XcodeProject.load(self.xcode_proj)

        # Add header paths to all targets in the project
        for source in self.ac.sources:
            file = self.xcode_find_file(project, source)
            if file:
                project.remove_file_by_id(file.get_id())

        # Save the project file
        project.save()

    def run(self):

        self.ac.index()
        self.xcode_add_headers()
        self.xcode_add_sources()



#!/usr/bin/env python

"""
Description: Generates a macosx shared library
"""

__author__ = "Veda Sadhak"
__license__ = "MIT"

import os
import shutil

from .auto_cmake import AutoCMake

class AutoCMakeLibSharedMac():

    def __init__(self, **cmake_config):

        # Creating instance
        self.ac = AutoCMake(**cmake_config)
        self.libs = cmake_config["libs"]

        # Setting flags
        self.flags = cmake_config["flags"]

        if "jni_dir" in cmake_config.keys():
            self.jni_dir = cmake_config["jni_dir"]
        else:
            self.jni_dir = None

        if "arch" in cmake_config.keys():
            self.arch = cmake_config["arch"]
        else:
            raise ("cmake_config['arch'] must be specified")

    def run(self):

        # Recursively adding all source
        for _dir in self.ac.include_dirs:
            self.ac.add_libraries(os.path.join(self.ac.proj_dir, _dir))
            self.ac.clear()

        # Adding the compile config
        self.ac.add("cmake_minimum_required(VERSION {})".format(self.ac.cmake_version))
        self.ac.add("project({} VERSION {})".format(self.ac.proj_name, self.ac.version))
        self.ac.add("set(CMAKE_CXX_STANDARD 11)")
        self.ac.add('set(CMAKE_CXX_FLAGS "${CMAKE_CXX_FLAGS}")')
        self.ac.add('set(CMAKE_OSX_ARCHITECTURES "{}")\n'.format(self.arch))

        # Setting flags
        self.ac.add('SET_PROPERTY(GLOBAL PROPERTY TARGET_SUPPORTS_SHARED_LIBS TRUE)\n')

        # Set headers and sources
        self.ac.add("set(SOURCES".format(self.ac.proj_name))
        for source in self.ac.sources:
            self.ac.add('    "{}"'.format(self.ac.get_posix_path(source)))
        for headers in self.ac.headers:
            self.ac.add('    "{}"'.format(self.ac.get_posix_path(headers)))
        self.ac.add(")\n")

        # Adding the shared lib
        self.ac.add("add_library({} SHARED {})\n".format(self.ac.proj_name, r"${SOURCES}"))

        # Setting flags
        self.ac.add("target_compile_definitions({} PUBLIC".format(self.ac.proj_name))
        for flag in self.flags:
            self.ac.add('    "{}"'.format(flag))
        self.ac.add(")\n")

        # Add JNI libs
        if self.jni_dir:
            self.ac.add('include_directories("{}/include")'.format(self.jni_dir))
            self.ac.add('link_directories("{}/include")'.format(self.jni_dir))
            self.ac.add('include_directories("{}/include/darwin")'.format(self.jni_dir))
            self.ac.add('link_directories("{}/include/darwin")\n'.format(self.jni_dir))

        # Setting shared lib properties
        self.ac.add('set_target_properties({} PROPERTIES COMPILE_FLAGS "-fPIC")\n'.format(self.ac.proj_name))

        # Link libraries
        for lib in self.libs:
            self.ac.add('target_link_libraries({} {})\n'.format(self.ac.proj_name, self.ac.get_posix_path(lib)))

        # Adding include directories
        for include in self.ac.includes:
            if include not in self.ac.library_paths:
                self.ac.add('target_include_directories({} PUBLIC "{}")'.format(self.ac.proj_name, include))
        self.ac.add("")

        # Adding include directories
        for path in self.ac.library_paths:
            self.ac.add('target_include_directories({} PUBLIC "{}")'.format(self.ac.proj_name, path))
        self.ac.add("")

        # Writing main CMakeLists.txt
        cmake_build_path = self.ac.get_posix_path(os.path.join(self.ac.proj_dir, "build"))
        if not os.path.exists(cmake_build_path):
            os.makedirs(cmake_build_path)
        self.ac.write(self.ac.build_dir)


#!/usr/bin/env python

"""
Description: Core module.
"""

__author__ = "Veda Sadhak"
__license__ = "MIT"

import os
import pathlib
import shutil
from .auto_cmake_indexer import AutoCMakeIndexer

class AutoCMake(AutoCMakeIndexer):

    def __init__(self, **kwargs):

        AutoCMakeIndexer.__init__(self, kwargs['proj_dir'])

        # Project Definition
        self.proj_name = kwargs['proj_name']
        self.version = kwargs['version']

        # CMake Definition
        self.cmake_version = kwargs['cmake_version']

        # Build & Export
        self.build_dir = self.get_posix_path(kwargs['build_dir'])

        # Include & Excludes
        self.include_dirs = kwargs['include_dirs']
        self.exclude_dirs = kwargs['exclude_dirs']
        self.exclude_paths = kwargs['exclude_paths']

        # Internal excludes
        self.exclude_paths.append(self.build_dir)

        # Library cache
        self.library_paths = []
        self.library_names = []

        # File cache
        self.sources = []
        self.headers = []
        self.includes = []
        self.startup = []
        self.linkers = []

    def clear(self):

        self.acake = ''

    def add(self, line):
        self.acake += (line + "\n")

    def write(self, path):

        with open(os.path.join(path, "CMakeLists.txt"), "w") as file:
            file.write(self.acake)

    def get_posix_path(self, path):

        return str(pathlib.PureWindowsPath(path).as_posix())

    def check_for_extensions(self, files, extensions):

        for file in files:
            for extension in extensions:
                if extension in file[-len(extension):]:
                    return True
        return False

    def construct_lib(self, lib_path, lib_name, lib_files):

        self.clear()
        self.add("add_library(")
        self.add("   " + lib_name)
        for lib_file in lib_files:

            # Check for exclusion
            is_excluded = False
            for exclude_path in self.exclude_paths:
                full_path = lib_path+"/"+lib_file
                if full_path[-len(exclude_path):] in exclude_path:
                    is_excluded = True
                    break

            # Add library
            if not is_excluded:
                if (not "CMakeLists" in lib_file):
                    self.add("    " + lib_file)
                if (".cpp" in lib_file) or (".c" in lib_file):
                    self.sources.append(os.path.join(lib_path,lib_file))

        self.add(")\n")
        self.add('target_include_directories({} PUBLIC "{}")'.format(lib_name, lib_path))
        self.write(lib_path)

        print("Added library {}".format(lib_name))

    def add_library(self, path):

        files = self.get_files(path)
        contains_source = self.check_for_extensions(files, [".c", ".cpp"])
        contains_header = self.check_for_extensions(files, [".h", ".hpp"])
        contains_startup = self.check_for_extensions(files, [".s"])
        contains_linker = self.check_for_extensions(files, [".ld"])

        if (len(files) > 0) and (contains_source):

            # Getting the library name while checking for repeats
            raw_lib_name = os.path.basename(path)
            lib_name_index = 1
            lib_name = raw_lib_name
            while (lib_name in self.library_names):
                lib_name = raw_lib_name + "_{}".format(lib_name_index)
                lib_name_index+=1

            # Constructing lib path
            lib_path = self.get_posix_path(path)

            # Adding the library
            if (lib_path not in self.library_paths) and (lib_name not in self.library_names):
                self.library_paths.append(lib_path)
                self.library_names.append(lib_name)
                self.construct_lib(lib_path, lib_name, files)

        if (len(files) > 0) and (contains_header):

            # Getting the library name while checking for repeats
            raw_lib_name = os.path.basename(path)
            lib_name_index = 1
            lib_name = raw_lib_name
            while (lib_name in self.library_names):
                lib_name = raw_lib_name + "_{}".format(lib_name_index)
                lib_name_index+=1

            # Constructing lib path
            lib_path = self.get_posix_path(path)

            # Adding the library
            if (lib_path not in self.library_paths) and (lib_name not in self.library_names):
                self.library_paths.append(lib_path)
                self.library_names.append(lib_name)
                self.construct_lib(lib_path, lib_name, [])

            # Adding include dirs
            self.includes.append(self.get_posix_path(path))

            # Adding the headers
            for file in files:

                # Check for exclusion
                is_excluded = False
                full_path = self.get_posix_path(os.path.join(path, file))
                for exclude_path in self.exclude_paths:
                    if full_path[-len(exclude_path):] in exclude_path:
                        is_excluded = True

                if not is_excluded:
                    if (".hpp" in file) or (".h" in file):
                        self.headers.append(full_path)

        if (len(files) > 0) and (contains_startup):

            # Adding include dirs
            self.includes.append(self.get_posix_path(path))

            # Adding the headers
            for file in files:
                if (".s" in file):
                    self.startup.append(self.get_posix_path(os.path.join(path, file)))

        if (len(files) > 0) and (contains_linker):

            # Adding include dirs
            self.includes.append(self.get_posix_path(path))

            # Adding the headers
            for file in files:
                if (".ld" in file):
                    self.linkers.append(self.get_posix_path(os.path.join(path, file)))

    def add_libraries(self, path):

        if (self.sub_dirs_exist(path)):
            for dir in self.get_sub_dirs(path):

                lib_path = os.path.join(path,dir)

                excluded = False
                for exclude_dir in self.exclude_dirs:
                    if exclude_dir == dir:
                        excluded = True

                if not excluded:
                    for exclude_path in self.exclude_paths:
                        if self.get_posix_path(exclude_path) in self.get_posix_path(lib_path):
                            excluded = True

                if not excluded:
                    self.add_libraries(os.path.join(path,dir))

        self.add_library(path)

    def index(self):

        for _dir in self.include_dirs:
            self.add_libraries(os.path.join(self.proj_dir, _dir))
            self.clear()

    def create_build_dir(self):
        if not os.path.exists(self.build_dir):
            os.makedirs(self.build_dir)

    def export(self):

        # Create directories
        include_dir = self.get_posix_path(os.path.join(self.build_dir, "include"))
        src_dir = self.get_posix_path(os.path.join(self.build_dir, "src"))
        if not os.path.exists(include_dir):
            os.makedirs(include_dir)
        if not os.path.exists(src_dir):
            os.makedirs(src_dir)

        # Copy over headers
        for header in self.headers:
            header_path, header_file = os.path.split(header)
            shutil.copyfile(header, os.path.join(include_dir, header_file))

        # Copy over sources
        for source in self.sources:
            source_path, source_file = os.path.split(source)
            shutil.copyfile(source, os.path.join(src_dir, source_file))







import os
import json
import unittest

from auto_cmake.auto_cmake import AutoCMake
from auto_cmake.auto_cmake_exe import AutoCMakeExe

# Source paths
proj_dir = os.path.abspath(os.path.join(os.getcwd(), "resources", "sample_c_proj"))
build_dir = os.path.abspath(os.path.join(proj_dir, "build"))

# Configuration
cmake_config = dict()
cmake_config['proj_name'] = 'sample_c_proj'
cmake_config['proj_dir'] = proj_dir
cmake_config['version'] = "2024.03.08"
cmake_config['cmake_version'] = '3.15'
cmake_config['include_dirs'] = [proj_dir]
cmake_config['libs'] = []
cmake_config['flags'] = []
cmake_config['exclude_dirs'] = []
cmake_config['exclude_paths'] = []
cmake_config['build_dir'] = build_dir

class TestAutoCMakeExe(unittest.TestCase):

    def test_create_build_dir(self):
        ac = AutoCMake(**cmake_config)
        ac.create_build_dir()

        build_dir = ac.get_posix_path(cmake_config['build_dir'])
        self.assertTrue(os.path.exists(build_dir))

    def test_export(self):
        ac = AutoCMake(**cmake_config)
        ac.index()
        ac.export()

        include_dir = ac.get_posix_path(os.path.join(cmake_config['build_dir'], "include"))
        src_dir = ac.get_posix_path(os.path.join(cmake_config['build_dir'], "src"))
        self.assertTrue(os.path.exists(include_dir))
        self.assertTrue(os.path.exists(src_dir))

if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python

"""
Description: Builds a source index.
"""

__author__ = "Veda Sadhak"
__license__ = "MIT"

import os

class AutoCMakeIndexer():

    def __init__(self, proj_dir):

        # Getting the project dir
        self.proj_dir = proj_dir

        # Directory indices
        self.all_dirs = []
        self.include_dirs = []

        # File indices
        self.files = dict()

    def get_sub_dirs(self, path):
        return next(os.walk(path))[1]

    def sub_dirs_exist(self, path):
        return (len(next(os.walk(path))[1]) > 0)

    def index_dirs(self, path):

        if (self.sub_dirs_exist(path)):
            for dir in self.get_sub_dirs(path):
                self.index_dirs(os.path.join(path, dir))

        self.all_dirs.append(path)

    def get_files(self, path):
        return next(os.walk(path))[2]


#!/usr/bin/env python

"""
Description: Generates an executable target
"""

__author__ = "Veda Sadhak"
__license__ = "MIT"

import os

from .auto_cmake import AutoCMake

class AutoCMakeLibSharedAndroid():

    def __init__(self, **cmake_config):

        # Creating instance
        self.ac = AutoCMake(**cmake_config)

        # Setting flags
        self.flags = cmake_config["flags"]

    def run(self):

        # Recursively adding all source
        for _dir in self.ac.include_dirs:
            self.ac.add_libraries(os.path.join(self.ac.proj_dir, _dir))
            self.ac.clear()

        # Adding the compile config
        self.ac.add("cmake_minimum_required(VERSION {})".format(self.ac.cmake_version))
        self.ac.add("project({} VERSION {})\n".format(self.ac.proj_name, self.ac.version))

        # Set headers and sources
        self.ac.add("add_library({}".format(self.ac.proj_name))
        self.ac.add("    SHARED")
        for source in self.ac.sources:
            self.ac.add('    "{}"'.format(self.ac.get_posix_path(source)))
        for headers in self.ac.headers:
            self.ac.add('    "{}"'.format(self.ac.get_posix_path(headers)))
        self.ac.add(")\n")


        # Setting flags
        self.ac.add("target_compile_definitions({} PUBLIC".format(self.ac.proj_name))
        for flag in self.flags:
           self.ac.add('    "{}"'.format(flag))
        self.ac.add(")\n")

        # Adding include directories
        for include in self.ac.includes:
            if include not in self.ac.library_paths:
                self.ac.add('target_include_directories({} PUBLIC "{}")'.format(self.ac.proj_name, include))
        self.ac.add("")

        # Adding include directories
        for path in self.ac.library_paths:
            self.ac.add('target_include_directories({} PUBLIC "{}")'.format(self.ac.proj_name, path))
        self.ac.add("")

        self.ac.add("find_library(".format(self.ac.proj_name))
        self.ac.add("    log-lib")
        self.ac.add("    log")
        self.ac.add(")\n")

        self.ac.add("target_link_libraries(")
        self.ac.add("    {}".format(self.ac.proj_name))
        self.ac.add(r"    ${log-lib}")
        self.ac.add(")\n")

        # Writing main CMakeLists.txt
        cmake_build_path = self.ac.get_posix_path(self.ac.build_dir)
        if not os.path.exists(cmake_build_path):
            os.makedirs(cmake_build_path)
        self.ac.write(self.ac.build_dir)


import os
import json
import unittest

from auto_cmake.auto_cmake import AutoCMake
from auto_cmake.auto_cmake_lib_shared_mac import AutoCMakeLibSharedMac

# Source paths
proj_dir = os.path.abspath(os.path.join(os.getcwd(), "resources", "sample_c_proj"))
build_dir = os.path.abspath(os.path.join(proj_dir, "build"))

# Configuration
cmake_config = dict()
cmake_config['proj_name'] = 'sample_c_proj'
cmake_config['proj_dir'] = proj_dir
cmake_config['version'] = "2024.03.08"
cmake_config['cmake_version'] = '3.15'
cmake_config['include_dirs'] = [proj_dir]
cmake_config['libs'] = []
cmake_config['flags'] = []
cmake_config['exclude_dirs'] = []
cmake_config['exclude_paths'] = []
cmake_config['build_dir'] = build_dir

# WIN Configuration
cmake_config['jni_dir'] = "/Library/Java/JavaVirtualMachines/jdk1.8.0_202.jdk/Contents/Home"

class TestAutoCMakeLibSharedMac(unittest.TestCase):

    def test_build_lib_shared_mac_intel(self):
        cmake_config['arch'] = "x86_64"
        ac = AutoCMakeLibSharedMac(**cmake_config)
        ac.run()

    def test_build_lib_shared_mac_m1(self):
        cmake_config['arch'] = "arm64"
        ac = AutoCMakeLibSharedMac(**cmake_config)
        ac.run()


if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages

setup(
    name='auto_cmake',
    version='2024.03.16',
    author='Veda Sadhak',
    author_email='vedasadhak@gmail.com',
    description='Automate setup of CMake projects',
    long_description=open('readme.md').read(),
    include_package_data=True,
    long_description_content_type='text/markdown',
    url='https://github.com/veda-s4dhak/auto-cmake.git',
    packages=find_packages(),
    install_requires=[
        'pbxproj'
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
    python_requires='>=3.7',
)
